==> oil-0.17.0.tar.gz: _devbuild/gen/types_asdl.py <==
from asdl import pybase
from pylib.collections_ import OrderedDict
from typing import Optional, List, Tuple, Dict, Any, cast, TYPE_CHECKING


from asdl import runtime  # For runtime.NO_SPID
from asdl.runtime import NewRecord, NewLeaf
from _devbuild.gen.hnode_asdl import color_e, hnode, hnode_e, hnode_t, Field

class bool_arg_type_t(pybase.SimpleObj):
  pass

class bool_arg_type_e(object):
  Undefined = bool_arg_type_t(1)
  Path = bool_arg_type_t(2)
  Int = bool_arg_type_t(3)
  Str = bool_arg_type_t(4)
  Other = bool_arg_type_t(5)

_bool_arg_type_str = {
  1: 'bool_arg_type.Undefined',
  2: 'bool_arg_type.Path',
  3: 'bool_arg_type.Int',
  4: 'bool_arg_type.Str',
  5: 'bool_arg_type.Other',
}

def bool_arg_type_str(val):
  # type: (bool_arg_type_t) -> str
  return _bool_arg_type_str[val]

class redir_arg_type_t(pybase.SimpleObj):
  pass

class redir_arg_type_e(object):
  Path = redir_arg_type_t(1)
  Desc = redir_arg_type_t(2)
  Here = redir_arg_type_t(3)

_redir_arg_type_str = {
  1: 'redir_arg_type.Path',
  2: 'redir_arg_type.Desc',
  3: 'redir_arg_type.Here',
}

def redir_arg_type_str(val):
  # type: (redir_arg_type_t) -> str
  return _redir_arg_type_str[val]

opt_group_t = int  # type alias for integer

class opt_group_i(object):
  StrictAll = 1
  YshUpgrade = 2
  YshAll = 3
  ARRAY_SIZE = 4

_opt_group_str = {
  1: 'opt_group.StrictAll',
  2: 'opt_group.YshUpgrade',
  3: 'opt_group.YshAll',
}

def opt_group_str(val):
  # type: (opt_group_t) -> str
  return _opt_group_str[val]

class lex_mode_t(pybase.SimpleObj):
  pass

class lex_mode_e(object):
  Undefined = lex_mode_t(1)
  Comment = lex_mode_t(2)
  ShCommand = lex_mode_t(3)
  Backtick = lex_mode_t(4)
  DBracket = lex_mode_t(5)
  SQ_Raw = lex_mode_t(6)
  DQ = lex_mode_t(7)
  SQ_C = lex_mode_t(8)
  Arith = lex_mode_t(9)
  ExtGlob = lex_mode_t(10)
  VSub_1 = lex_mode_t(11)
  VSub_2 = lex_mode_t(12)
  VSub_ArgUnquoted = lex_mode_t(13)
  VSub_ArgDQ = lex_mode_t(14)
  BashRegex = lex_mode_t(15)
  BashRegexChars = lex_mode_t(16)
  FuncParens = lex_mode_t(17)
  PrintfOuter = lex_mode_t(18)
  PrintfPercent = lex_mode_t(19)
  Expr = lex_mode_t(20)
  QSN = lex_mode_t(21)

_lex_mode_str = {
  1: 'lex_mode.Undefined',
  2: 'lex_mode.Comment',
  3: 'lex_mode.ShCommand',
  4: 'lex_mode.Backtick',
  5: 'lex_mode.DBracket',
  6: 'lex_mode.SQ_Raw',
  7: 'lex_mode.DQ',
  8: 'lex_mode.SQ_C',
  9: 'lex_mode.Arith',
  10: 'lex_mode.ExtGlob',
  11: 'lex_mode.VSub_1',
  12: 'lex_mode.VSub_2',
  13: 'lex_mode.VSub_ArgUnquoted',
  14: 'lex_mode.VSub_ArgDQ',
  15: 'lex_mode.BashRegex',
  16: 'lex_mode.BashRegexChars',
  17: 'lex_mode.FuncParens',
  18: 'lex_mode.PrintfOuter',
  19: 'lex_mode.PrintfPercent',
  20: 'lex_mode.Expr',
  21: 'lex_mode.QSN',
}

def lex_mode_str(val):
  # type: (lex_mode_t) -> str
  return _lex_mode_str[val]

class cmd_mode_t(pybase.SimpleObj):
  pass

class cmd_mode_e(object):
  Normal = cmd_mode_t(1)
  Func = cmd_mode_t(2)

_cmd_mode_str = {
  1: 'cmd_mode.Normal',
  2: 'cmd_mode.Func',
}

def cmd_mode_str(val):
  # type: (cmd_mode_t) -> str
  return _cmd_mode_str[val]

==> oil-0.18.0.tar.gz: _devbuild/gen/types_asdl.py <==
from asdl import pybase
from pylib.collections_ import OrderedDict
from typing import Optional, List, Tuple, Dict, Any, cast, TYPE_CHECKING


from asdl import runtime  # For runtime.NO_SPID
from asdl.runtime import NewRecord, NewLeaf
from _devbuild.gen.hnode_asdl import color_e, hnode, hnode_e, hnode_t, Field

class bool_arg_type_t(pybase.SimpleObj):
  pass

class bool_arg_type_e(object):
  Undefined = bool_arg_type_t(1)
  Path = bool_arg_type_t(2)
  Int = bool_arg_type_t(3)
  Str = bool_arg_type_t(4)
  Other = bool_arg_type_t(5)

_bool_arg_type_str = {
  1: 'bool_arg_type.Undefined',
  2: 'bool_arg_type.Path',
  3: 'bool_arg_type.Int',
  4: 'bool_arg_type.Str',
  5: 'bool_arg_type.Other',
}

def bool_arg_type_str(val):
  # type: (bool_arg_type_t) -> str
  return _bool_arg_type_str[val]

class redir_arg_type_t(pybase.SimpleObj):
  pass

class redir_arg_type_e(object):
  Path = redir_arg_type_t(1)
  Desc = redir_arg_type_t(2)
  Here = redir_arg_type_t(3)

_redir_arg_type_str = {
  1: 'redir_arg_type.Path',
  2: 'redir_arg_type.Desc',
  3: 'redir_arg_type.Here',
}

def redir_arg_type_str(val):
  # type: (redir_arg_type_t) -> str
  return _redir_arg_type_str[val]

opt_group_t = int  # type alias for integer

class opt_group_i(object):
  StrictAll = 1
  YshUpgrade = 2
  YshAll = 3
  ARRAY_SIZE = 4

_opt_group_str = {
  1: 'opt_group.StrictAll',
  2: 'opt_group.YshUpgrade',
  3: 'opt_group.YshAll',
}

def opt_group_str(val):
  # type: (opt_group_t) -> str
  return _opt_group_str[val]

class lex_mode_t(pybase.SimpleObj):
  pass

class lex_mode_e(object):
  Undefined = lex_mode_t(1)
  Comment = lex_mode_t(2)
  ShCommand = lex_mode_t(3)
  Backtick = lex_mode_t(4)
  DBracket = lex_mode_t(5)
  SQ_Raw = lex_mode_t(6)
  DQ = lex_mode_t(7)
  SQ_C = lex_mode_t(8)
  Arith = lex_mode_t(9)
  ExtGlob = lex_mode_t(10)
  VSub_1 = lex_mode_t(11)
  VSub_2 = lex_mode_t(12)
  VSub_ArgUnquoted = lex_mode_t(13)
  VSub_ArgDQ = lex_mode_t(14)
  BashRegex = lex_mode_t(15)
  BashRegexChars = lex_mode_t(16)
  FuncParens = lex_mode_t(17)
  PrintfOuter = lex_mode_t(18)
  PrintfPercent = lex_mode_t(19)
  Expr = lex_mode_t(20)
  QSN = lex_mode_t(21)

_lex_mode_str = {
  1: 'lex_mode.Undefined',
  2: 'lex_mode.Comment',
  3: 'lex_mode.ShCommand',
  4: 'lex_mode.Backtick',
  5: 'lex_mode.DBracket',
  6: 'lex_mode.SQ_Raw',
  7: 'lex_mode.DQ',
  8: 'lex_mode.SQ_C',
  9: 'lex_mode.Arith',
  10: 'lex_mode.ExtGlob',
  11: 'lex_mode.VSub_1',
  12: 'lex_mode.VSub_2',
  13: 'lex_mode.VSub_ArgUnquoted',
  14: 'lex_mode.VSub_ArgDQ',
  15: 'lex_mode.BashRegex',
  16: 'lex_mode.BashRegexChars',
  17: 'lex_mode.FuncParens',
  18: 'lex_mode.PrintfOuter',
  19: 'lex_mode.PrintfPercent',
  20: 'lex_mode.Expr',
  21: 'lex_mode.QSN',
}

def lex_mode_str(val):
  # type: (lex_mode_t) -> str
  return _lex_mode_str[val]

class cmd_mode_t(pybase.SimpleObj):
  pass

class cmd_mode_e(object):
  Shell = cmd_mode_t(1)
  Func = cmd_mode_t(2)
  Proc = cmd_mode_t(3)

_cmd_mode_str = {
  1: 'cmd_mode.Shell',
  2: 'cmd_mode.Func',
  3: 'cmd_mode.Proc',
}

def cmd_mode_str(val):
  # type: (cmd_mode_t) -> str
  return _cmd_mode_str[val]
